@@ -6,7 +6,7 @@ class Deployment():
         A model deployment
     '''
 
-    def __init__(self, client, deploymentId=None, name=None, status=None, description=None, deployedAt=None, createdAt=None, projectId=None, modelId=None, modelVersion=None, callsPerSecond=None, autoDeploy=None, regions=None, error=None, refreshSchedules={}):
+    def __init__(self, client, deploymentId=None, name=None, status=None, description=None, deployedAt=None, createdAt=None, projectId=None, modelId=None, modelVersion=None, featureGroupId=None, featureGroupVersion=None, callsPerSecond=None, autoDeploy=None, regions=None, error=None, refreshSchedules={}):
         self.client = client
         self.id = deploymentId
         self.deployment_id = deploymentId
@@ -18,6 +18,8 @@ class Deployment():
         self.project_id = projectId
         self.model_id = modelId
         self.model_version = modelVersion
+        self.feature_group_id = featureGroupId
+        self.feature_group_version = featureGroupVersion
         self.calls_per_second = callsPerSecond
         self.auto_deploy = autoDeploy
         self.regions = regions
@@ -26,13 +28,13 @@ class Deployment():
             RefreshSchedule, refreshSchedules)
 
     def __repr__(self):
-        return f"Deployment(deployment_id={repr(self.deployment_id)}, name={repr(self.name)}, status={repr(self.status)}, description={repr(self.description)}, deployed_at={repr(self.deployed_at)}, created_at={repr(self.created_at)}, project_id={repr(self.project_id)}, model_id={repr(self.model_id)}, model_version={repr(self.model_version)}, calls_per_second={repr(self.calls_per_second)}, auto_deploy={repr(self.auto_deploy)}, regions={repr(self.regions)}, error={repr(self.error)}, refresh_schedules={repr(self.refresh_schedules)})"
+        return f"Deployment(deployment_id={repr(self.deployment_id)}, name={repr(self.name)}, status={repr(self.status)}, description={repr(self.description)}, deployed_at={repr(self.deployed_at)}, created_at={repr(self.created_at)}, project_id={repr(self.project_id)}, model_id={repr(self.model_id)}, model_version={repr(self.model_version)}, feature_group_id={repr(self.feature_group_id)}, feature_group_version={repr(self.feature_group_version)}, calls_per_second={repr(self.calls_per_second)}, auto_deploy={repr(self.auto_deploy)}, regions={repr(self.regions)}, error={repr(self.error)}, refresh_schedules={repr(self.refresh_schedules)})"
 
     def __eq__(self, other):
         return self.__class__ == other.__class__ and self.id == other.id
 
     def to_dict(self):
-        return {'deployment_id': self.deployment_id, 'name': self.name, 'status': self.status, 'description': self.description, 'deployed_at': self.deployed_at, 'created_at': self.created_at, 'project_id': self.project_id, 'model_id': self.model_id, 'model_version': self.model_version, 'calls_per_second': self.calls_per_second, 'auto_deploy': self.auto_deploy, 'regions': self.regions, 'error': self.error, 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None}
+        return {'deployment_id': self.deployment_id, 'name': self.name, 'status': self.status, 'description': self.description, 'deployed_at': self.deployed_at, 'created_at': self.created_at, 'project_id': self.project_id, 'model_id': self.model_id, 'model_version': self.model_version, 'feature_group_id': self.feature_group_id, 'feature_group_version': self.feature_group_version, 'calls_per_second': self.calls_per_second, 'auto_deploy': self.auto_deploy, 'regions': self.regions, 'error': self.error, 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None}
 
     def refresh(self):
         self.__dict__.update(self.describe().__dict__)
@@ -53,6 +55,9 @@ class Deployment():
     def set_model_version(self, model_version):
         return self.client.set_deployment_model_version(self.deployment_id, model_version)
 
+    def set_feature_group_version(self, feature_group_version):
+        return self.client.set_deployment_feature_group_version(self.deployment_id, feature_group_version)
+
     def start(self):
         return self.client.start_deployment(self.deployment_id)
 
